@@ -232,8 +232,10 @@ impl<'a, I: Tokens> Parser<I> {
                 tok!("import") => {
                     let import = self.parse_ident_name()?;
                     if self.input.syntax().import_meta() && is!(self, '.') {
-                        if !self.ctx().module {
-                            syntax_error!(self, SyntaxError::ImportMetaInScript);
+                        self.state.found_module_item = true;
+                        if !self.ctx().can_be_module {
+                            let span = span!(self, start);
+                            self.emit_err(span, SyntaxError::ImportMetaInScript);
                         }
                         return self
                             .parse_import_meta_prop(import)
